// Author : Pierre Vuillemin (2016)
// License : CECILL

function newVar = %s_a_sopiVar(b, var)
   // Overloading of the addition between a matrix and a sopiVar.
   //
   // Inputs
   // ------
   // b (matrix): a matrix
   // var (sopiVar): a sopiVar
   //
   // Returns
   // -------
   // A sopiVar containing a tree representing the operation.
   //
   // Example
   // -------
   // sopi_begin()
   // x = sopi_var(1)
   // y = 3 + x
   // y.operator // should be "sum"
   // y.args(1)  // should be a constant sopiVar containing 3
   // y.args(2)  // should be x
   //
   sopi_print(5,"Performing Matrix + sopiVar.\n")
   if isempty(b) | and(b==0) then
      newVar = var;
   else
      newSize        = sopi_checkSizesCoherence(b, var, "sum");      
      if isscalar(b) then
         b           = b*ones(newSize(1),newSize(2));
      end
      bvar              = sopi_constant(b);
      newVar            = sopi_newVar()
      newVar.size       = newSize
      newVar.operator   = "sum"
      newVar.args       = list(bvar, var)
   end
endfunction
