// Author : Pierre Vuillemin (2016)
// License : CECILL

function [outVar, fopt, info] = sopi_solve(problem, method)
   // Solves an optimisation problem.
   //
   // Calling Sequence
   // sopi_solve(problem, method)
   //
   // Parameters
   // problem; a sopiPro
   // method: the name of the optimisation method to use
   //
   //
   tic()
   if problem.class == 0 then
      if argn(2) < 2
         method = "karmarkar"
      end
      sol = sopi_callLPSolver(problem, method)
   else
      error('Only LP problems are handled right now')
   end
   
   optVar = list()
   for v = problem.varList
      idx         = sopi_getVarIdxInProblem(problem, v)
      v.opt       = sol.xopt(idx)
      optVar($+1) = v
   end
   outVar            = optVar;
   fopt              = objective
   info              = struct()
   info.elapsedTime  = toc();
   // Assigning output optimal values
   clear v
   objective      = problem.objective
   objective.opt  = sol.fopt
   optVar($+1)    = objective
   exVars   = sopi_getExistingSopiVar()
   couples  = list()
   for v = exVars
      for vopt = optVar
         if vopt.id == v(1).id
            couples($+1) = list(v(2), vopt)
         end
      end
   end
   out      = [];
   arg      = [];
   for i = 1:length(couples)
      out = [out,couples(i)(1)]
//      arg = [arg,"["+strcat(string(couples(i)(2)),";")+"]"];
      arg = [arg,"couples(" + string(i) + ")(2)"];
   end
   exStr = "[" + strcat(out,',') + "] = resume(" + strcat(arg,",")+");";
   execstr(exStr);

endfunction


function out = sopi_callLPSolver(problem, method)
   select method
   case "karmarkar"
      [xopt, fopt, exitflag, iter, yopt] = karmarkar(problem.Aeq, problem.beq, problem.fun.c, [], [], [], [], [], -problem.A, -problem.b, problem.lb, problem.ub)
      out      = struct()
      out.xopt = xopt
      out.fopt = fopt + problem.fun.q
      
   end
endfunction
