// Author : Pierre Vuillemin (2016)
// License : CECILL

function  var = sopi_var(dim1, varargin)
   // Creates an optimisation variable.
   //
   // Calling Sequence
   //    var = sopi_var(m)
   //    var = sopi_var(m, n)
   //
   // Parameters
   // m: row dimension
   // n: column dimension (default is 1)
   // var: the sopiVar
   //
   // Description
   // This routine returns a sopiVar object which can be used to build functions
   // and constraints in order to formulate optimisation problems.
   // For that purpose, most common operators have been overloaded and can be used
   // with sopiVars.
   //
   // Examples
   // To create a 3x2 matrix sopiVar:
   // sopi_begin();
   // x = sopi_var(3,2);
   // disp(x)
   //
   if length(varargin) == 0 then
       s = [dim1, 1]
   elseif length(varargin) == 1 then
       s = [dim1, varargin(1)]
   else
       sopi_error("Invalid number of inputs, 2 allowed")
   end
   sopi_print(2,"Creation of a sopiVar of size %dx%d.\n",s(1),s(2))
   var      = sopi_newVar()
   var.size = s
endfunction
